@@ -36,6 +36,7 @@ class Config(object):
     :ivar edge_index: Name of the edge index. Defaults to "edge". 
     :ivar autoindex: Enable auto indexing. Defaults to True.
     :ivar server_scripts: Scripts are defined server side. Defaults to False.
+    :ivar timeout: Optional timeout in seconds. Defaults to None
 
     Example:
 
@@ -47,7 +48,7 @@ class Config(object):
 
     """
 
-    def __init__(self, root_uri, username=None, password=None):
+    def __init__(self, root_uri, username=None, password=None, timeout=None):
         self.root_uri = root_uri
         self.username = username
         self.password = password
@@ -61,6 +62,7 @@ class Config(object):
         self.edge_index = "edge"
         self.autoindex = True         # Titan Client sets autoindex to false
         self.server_scripts = False
+        self.timeout = timeout
         
         # Set the default log level and log handler
         self.set_logger(self.log_level, self.log_handler)
@@ -85,8 +87,26 @@ class Config(object):
         #log = get_logger(__name__)
         bulbs_logger.setLevel(log_level)
         self.log_level = log_level 
+        
         if log_handler is not None:
-            bulbs_logger.addHandler(log_handler())
+            # Don't add log handler twice to prevent duplicate output
+            self._maybe_add_log_handler(log_handler)
+
+    def _maybe_add_log_handler(self, log_handler):
+        """
+        Adds log handler if an instance of it hasn't already been added.
+
+        :param log_handler: Python log handler.
+        :type log_handler: logging.Handler
+        
+        :rtype: None
+
+        """
+        for handler in bulbs_logger.handlers:
+            if isinstance(handler, log_handler):
+                return
+        # log handler hasn't been added yet so add it
+        bulbs_logger.addHandler(log_handler())
 
     def set_neo4j_heroku(self, log_level=ERROR, log_handler=None):
         """
